@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.701';
+our $VERSION = '1.711';
 
 use Exporter qw( import );
 
@@ -261,8 +261,8 @@ sub table_char_width { [
 [   0xb41,    0xb44, 0],
 [   0xb45,    0xb4c, 1],
 [   0xb4d,    0xb4d, 0],
-[   0xb4e,    0xb55, 1],
-[   0xb56,    0xb56, 0],
+[   0xb4e,    0xb54, 1],
+[   0xb55,    0xb56, 0],
 [   0xb57,    0xb61, 1],
 [   0xb62,    0xb63, 0],
 [   0xb64,    0xb81, 1],
@@ -307,7 +307,9 @@ sub table_char_width { [
 [   0xd4d,    0xd4d, 0],
 [   0xd4e,    0xd61, 1],
 [   0xd62,    0xd63, 0],
-[   0xd64,    0xdc9, 1],
+[   0xd64,    0xd80, 1],
+[   0xd81,    0xd81, 0],
+[   0xd82,    0xdc9, 1],
 [   0xdca,    0xdca, 0],
 [   0xdcb,    0xdd1, 1],
 [   0xdd2,    0xdd4, 0],
@@ -423,8 +425,8 @@ sub table_char_width { [
 [  0x1a7d,   0x1a7e, 1],
 [  0x1a7f,   0x1a7f, 0],
 [  0x1a80,   0x1aaf, 1],
-[  0x1ab0,   0x1abe, 0],
-[  0x1abf,   0x1aff, 1],
+[  0x1ab0,   0x1ac0, 0],
+[  0x1ac1,   0x1aff, 1],
 [  0x1b00,   0x1b03, 0],
 [  0x1b04,   0x1b33, 1],
 [  0x1b34,   0x1b34, 0],
@@ -753,15 +755,11 @@ sub table_char_width { [
 [  0x3130,   0x3130, 1],
 [  0x3131,   0x318e, 2],
 [  0x318f,   0x318f, 1],
-[  0x3190,   0x31ba, 2],
-[  0x31bb,   0x31bf, 1],
-[  0x31c0,   0x31e3, 2],
+[  0x3190,   0x31e3, 2],
 [  0x31e4,   0x31ef, 1],
 [  0x31f0,   0x321e, 2],
 [  0x321f,   0x321f, 1],
-[  0x3220,   0x32fe, 2],
-[  0x32ff,   0x32ff, 1],
-[  0x3300,   0x4dbf, 2],
+[  0x3220,   0x4dbf, 2],
 [  0x4dc0,   0x4dff, 1],
 [  0x4e00,   0xa48c, 2],
 [  0xa48d,   0xa48f, 1],
@@ -782,7 +780,9 @@ sub table_char_width { [
 [  0xa80b,   0xa80b, 0],
 [  0xa80c,   0xa824, 1],
 [  0xa825,   0xa826, 0],
-[  0xa827,   0xa8c3, 1],
+[  0xa827,   0xa82b, 1],
+[  0xa82c,   0xa82c, 0],
+[  0xa82d,   0xa8c3, 1],
 [  0xa8c4,   0xa8c5, 0],
 [  0xa8c6,   0xa8df, 1],
 [  0xa8e0,   0xa8f1, 0],
@@ -882,7 +882,9 @@ sub table_char_width { [
 [ 0x10ae5,  0x10ae6, 0],
 [ 0x10ae7,  0x10d23, 1],
 [ 0x10d24,  0x10d27, 0],
-[ 0x10d28,  0x10f45, 1],
+[ 0x10d28,  0x10eaa, 1],
+[ 0x10eab,  0x10eac, 0],
+[ 0x10ead,  0x10f45, 1],
 [ 0x10f46,  0x10f50, 0],
 [ 0x10f51,  0x11000, 1],
 [ 0x11001,  0x11001, 0],
@@ -912,7 +914,9 @@ sub table_char_width { [
 [ 0x111b6,  0x111be, 0],
 [ 0x111bf,  0x111c8, 1],
 [ 0x111c9,  0x111cc, 0],
-[ 0x111cd,  0x1122e, 1],
+[ 0x111cd,  0x111ce, 1],
+[ 0x111cf,  0x111cf, 0],
+[ 0x111d0,  0x1122e, 1],
 [ 0x1122f,  0x11231, 0],
 [ 0x11232,  0x11233, 1],
 [ 0x11234,  0x11234, 0],
@@ -982,7 +986,13 @@ sub table_char_width { [
 [ 0x1182f,  0x11837, 0],
 [ 0x11838,  0x11838, 1],
 [ 0x11839,  0x1183a, 0],
-[ 0x1183b,  0x119d3, 1],
+[ 0x1183b,  0x1193a, 1],
+[ 0x1193b,  0x1193c, 0],
+[ 0x1193d,  0x1193d, 1],
+[ 0x1193e,  0x1193e, 0],
+[ 0x1193f,  0x11942, 1],
+[ 0x11943,  0x11943, 0],
+[ 0x11944,  0x119d3, 1],
 [ 0x119d4,  0x119d7, 0],
 [ 0x119d8,  0x119d9, 1],
 [ 0x119da,  0x119db, 0],
@@ -1048,11 +1058,16 @@ sub table_char_width { [
 [ 0x16f8f,  0x16f92, 0],
 [ 0x16f93,  0x16fdf, 1],
 [ 0x16fe0,  0x16fe3, 2],
-[ 0x16fe4,  0x16fff, 1],
+[ 0x16fe4,  0x16fe4, 0],
+[ 0x16fe5,  0x16fef, 1],
+[ 0x16ff0,  0x16ff1, 2],
+[ 0x16ff2,  0x16fff, 1],
 [ 0x17000,  0x187f7, 2],
 [ 0x187f8,  0x187ff, 1],
-[ 0x18800,  0x18af2, 2],
-[ 0x18af3,  0x1afff, 1],
+[ 0x18800,  0x18cd5, 2],
+[ 0x18cd6,  0x18cff, 1],
+[ 0x18d00,  0x18d08, 2],
+[ 0x18d09,  0x1afff, 1],
 [ 0x1b000,  0x1b11e, 2],
 [ 0x1b11f,  0x1b14f, 1],
 [ 0x1b150,  0x1b152, 2],
@@ -1169,34 +1184,38 @@ sub table_char_width { [
 [ 0x1f6cd,  0x1f6cf, 1],
 [ 0x1f6d0,  0x1f6d2, 2],
 [ 0x1f6d3,  0x1f6d4, 1],
-[ 0x1f6d5,  0x1f6d5, 2],
-[ 0x1f6d6,  0x1f6ea, 1],
+[ 0x1f6d5,  0x1f6d7, 2],
+[ 0x1f6d8,  0x1f6ea, 1],
 [ 0x1f6eb,  0x1f6ec, 2],
 [ 0x1f6ed,  0x1f6f3, 1],
-[ 0x1f6f4,  0x1f6fa, 2],
-[ 0x1f6fb,  0x1f7df, 1],
+[ 0x1f6f4,  0x1f6fc, 2],
+[ 0x1f6fd,  0x1f7df, 1],
 [ 0x1f7e0,  0x1f7eb, 2],
-[ 0x1f7ec,  0x1f90c, 1],
-[ 0x1f90d,  0x1f971, 2],
-[ 0x1f972,  0x1f972, 1],
-[ 0x1f973,  0x1f976, 2],
-[ 0x1f977,  0x1f979, 1],
-[ 0x1f97a,  0x1f9a2, 2],
-[ 0x1f9a3,  0x1f9a4, 1],
-[ 0x1f9a5,  0x1f9aa, 2],
-[ 0x1f9ab,  0x1f9ad, 1],
-[ 0x1f9ae,  0x1f9ca, 2],
-[ 0x1f9cb,  0x1f9cc, 1],
+[ 0x1f7ec,  0x1f90b, 1],
+[ 0x1f90c,  0x1f93a, 2],
+[ 0x1f93b,  0x1f93b, 1],
+[ 0x1f93c,  0x1f945, 2],
+[ 0x1f946,  0x1f946, 1],
+[ 0x1f947,  0x1f978, 2],
+[ 0x1f979,  0x1f979, 1],
+[ 0x1f97a,  0x1f9cb, 2],
+[ 0x1f9cc,  0x1f9cc, 1],
 [ 0x1f9cd,  0x1f9ff, 2],
 [ 0x1fa00,  0x1fa6f, 1],
-[ 0x1fa70,  0x1fa73, 2],
-[ 0x1fa74,  0x1fa77, 1],
+[ 0x1fa70,  0x1fa74, 2],
+[ 0x1fa75,  0x1fa77, 1],
 [ 0x1fa78,  0x1fa7a, 2],
 [ 0x1fa7b,  0x1fa7f, 1],
-[ 0x1fa80,  0x1fa82, 2],
-[ 0x1fa83,  0x1fa8f, 1],
-[ 0x1fa90,  0x1fa95, 2],
-[ 0x1fa96,  0x1ffff, 1],
+[ 0x1fa80,  0x1fa86, 2],
+[ 0x1fa87,  0x1fa8f, 1],
+[ 0x1fa90,  0x1faa8, 2],
+[ 0x1faa9,  0x1faaf, 1],
+[ 0x1fab0,  0x1fab6, 2],
+[ 0x1fab7,  0x1fabf, 1],
+[ 0x1fac0,  0x1fac2, 2],
+[ 0x1fac3,  0x1facf, 1],
+[ 0x1fad0,  0x1fad6, 2],
+[ 0x1fad7,  0x1ffff, 1],
 [ 0x20000,  0x2fffd, 2],
 [ 0x2fffe,  0x2ffff, 1],
 [ 0x30000,  0x3fffd, 2],
